try{!function(){var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{},d=(new e.Error).stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="367ab119-9518-4bce-8289-9d04538cdd51",e._sentryDebugIdIdentifier="sentry-dbid-367ab119-9518-4bce-8289-9d04538cdd51")}()}catch(e){}!function(){try{("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{}).SENTRY_RELEASE={id:"agent-cli@2026.05.20-2b5dd59"}}catch(e){}}(),exports.id=3746,exports.ids=[3746],exports.modules={"./src/commands/disable.ts":(e,d,n)=>{n.r(d),n.d(d,{handleMcpDisable:()=>l});var o=n("../../node_modules/.pnpm/chalk@5.4.1/node_modules/chalk/source/index.js"),s=n("./src/console-io.ts"),t=n("./src/mcp/disabled-store.ts"),i=n("./src/mcp/project-paths.ts"),r=function(e,d,n,o){return new(n||(n=Promise))((function(s,t){function i(e){try{l(o.next(e))}catch(e){t(e)}}function r(e){try{l(o.throw(e))}catch(e){t(e)}}function l(e){var d;e.done?s(e.value):(d=e.value,d instanceof n?d:new n((function(e){e(d)}))).then(i,r)}l((o=o.apply(e,d||[])).next())}))};function l(e,d){return r(this,void 0,void 0,(function*(){var e;try{const e=process.cwd(),{disabledPath:n}=(0,i.C)(e),r=new t.P(n),l=yield r.isServerDisabled(d);l||(yield r.addDisabledServer(d)),l?(0,s.OT)(o.Ay.yellow(`MCP server '${d}' was already disabled`)):(0,s.OT)(o.Ay.green(`✓ Disabled MCP server: ${d}`)+"\n"+o.Ay.dim("The server will no longer be loaded or prompted for approval.")),process.exit(0)}catch(d){const n=null!==(e=null==d?void 0:d.message)&&void 0!==e?e:String(d);(0,s.p2)(o.Ay.red(`Failed to disable MCP server: ${n}`)),process.exit(1)}}))}}};