try{!function(){var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{},n=(new e.Error).stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="9a8d28ce-e06a-48e3-b527-822ac16bff42",e._sentryDebugIdIdentifier="sentry-dbid-9a8d28ce-e06a-48e3-b527-822ac16bff42")}()}catch(e){}!function(){try{("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{}).SENTRY_RELEASE={id:"agent-cli@2026.05.20-2b5dd59"}}catch(e){}}(),exports.id=8972,exports.ids=[8972],exports.modules={"./src/commands/set-channel.ts":(e,n,t)=>{t.r(n),t.d(n,{handleSetChannel:()=>d});var o=t("../cursor-config/dist/index.js"),i=t("./src/console-io.ts"),s=function(e,n,t,o){return new(t||(t=Promise))((function(i,s){function d(e){try{c(o.next(e))}catch(e){s(e)}}function a(e){try{c(o.throw(e))}catch(e){s(e)}}function c(e){var n;e.done?i(e.value):(n=e.value,n instanceof t?n:new t((function(e){e(n)}))).then(d,a)}c((o=o.apply(e,n||[])).next())}))};function d(e,n){return s(this,void 0,void 0,(function*(){const t=o.Kr.pick({channel:!0}).safeParse({channel:n});t.success?(yield e.transform((e=>Object.assign(Object.assign({},e),{channel:t.data.channel}))),process.exit(0)):(0,i.uQ)(1,`Invalid channel "${n}"`)}))}}};