try{!function(){var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{},t=(new e.Error).stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="8c7cfb22-5611-445e-8413-9b2ca8032f0a",e._sentryDebugIdIdentifier="sentry-dbid-8c7cfb22-5611-445e-8413-9b2ca8032f0a")}()}catch(e){}!function(){try{("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{}).SENTRY_RELEASE={id:"agent-cli@2026.05.20-2b5dd59"}}catch(e){}}(),exports.id=9262,exports.ids=[9262],exports.modules={"./src/commands/status.ts":(e,t,s)=>{s.r(t),s.d(t,{gatherStatusInfo:()=>r,handleStatus:()=>d});var n=s("../proto/dist/generated/aiserver/v1/dashboard_pb.js"),a=s("../../node_modules/.pnpm/chalk@5.4.1/node_modules/chalk/source/index.js"),i=s("./src/console-io.ts"),o=function(e,t,s,n){return new(s||(s=Promise))((function(a,i){function o(e){try{d(n.next(e))}catch(e){i(e)}}function r(e){try{d(n.throw(e))}catch(e){i(e)}}function d(e){var t;e.done?a(e.value):(t=e.value,t instanceof s?t:new s((function(e){e(t)}))).then(o,r)}d((n=n.apply(e,t||[])).next())}))};function r(e,t){return o(this,void 0,void 0,(function*(){const s=yield e.getAccessToken(),a=yield e.getRefreshToken();if(s&&a)try{const e=yield t.getMe(new n.GetMeRequest({})),s=null!=e.email||null!=e.userId||null!=e.firstName||null!=e.lastName||null!=e.teamId||null!=e.createdAt?{email:e.email,userId:e.userId,firstName:e.firstName,lastName:e.lastName,teamId:e.teamId,createdAt:e.createdAt}:void 0;return{status:"authenticated",isAuthenticated:!0,hasAccessToken:!0,hasRefreshToken:!0,message:null!=e.email?void 0:"Logged in (user details not available)",userInfo:s}}catch(e){return{status:"authenticated",isAuthenticated:!0,hasAccessToken:!0,hasRefreshToken:!0,message:"Logged in (unable to fetch user details)"}}return s?{status:"partially-authenticated",isAuthenticated:!1,hasAccessToken:!0,hasRefreshToken:!1,message:"Partially authenticated (missing refresh token)"}:{status:"unauthenticated",isAuthenticated:!1,hasAccessToken:!1,hasRefreshToken:!1,message:"Not logged in"}}))}function d(e,t){return o(this,arguments,void 0,(function*(e,t,s={}){var n;const o=null!==(n=s.format)&&void 0!==n?n:"text";let d=0;try{const s=yield r(e,t);"json"===o?(0,i.OT)(JSON.stringify(s,null,2)):(0,i.OT)(function(e){var t;switch(e.status){case"authenticated":{const t=e.userInfo,s=(null==t?void 0:t.email)?`Logged in as ${t.email}`:(null==t?void 0:t.userId)?`Logged in as user id ${t.userId}`:"Login successful!",n=[`${a.Ay.green("✓")} ${s}`];return e.message&&n.push(e.message),n.join("\n")}case"partially-authenticated":case"unauthenticated":return a.Ay.red(null!==(t=e.message)&&void 0!==t?t:"Not logged in")}}(s))}catch(e){d=1;const t=e instanceof Error?e.message:String(e);"json"===o?(0,i.OT)(JSON.stringify({status:"error",message:`Status check error: ${t}`},null,2)):(0,i.p2)(a.Ay.red(`Status check error: ${t}`))}finally{process.exit(d)}}))}}};