try{!function(){var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{},t=(new e.Error).stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="63db8baa-7784-4c69-83f8-3ea4e29f28b9",e._sentryDebugIdIdentifier="sentry-dbid-63db8baa-7784-4c69-83f8-3ea4e29f28b9")}()}catch(e){}!function(){try{("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{}).SENTRY_RELEASE={id:"agent-cli@2026.05.20-2b5dd59"}}catch(e){}}(),exports.id=3647,exports.ids=[3647],exports.modules={"./src/commands/about.ts":(e,t,n)=>{n.r(t),n.d(t,{gatherAboutInfo:()=>f,handleAbout:()=>g});var l=n("node:os"),s=n.n(l),o=n("../proto/dist/generated/aiserver/v1/dashboard_pb.js"),a=n("../../node_modules/.pnpm/chalk@5.4.1/node_modules/chalk/source/index.js"),r=n("./src/console-io.ts"),u=n("./src/state/session.ts"),i=n("./src/utils/terminal-environment.ts"),d=function(e,t,n,l){return new(n||(n=Promise))((function(s,o){function a(e){try{u(l.next(e))}catch(e){o(e)}}function r(e){try{u(l.throw(e))}catch(e){o(e)}}function u(e){var t;e.done?s(e.value):(t=e.value,t instanceof n?t:new n((function(e){e(t)}))).then(a,r)}u((l=l.apply(e,t||[])).next())}))};const c=20;function f(e,t,n){return d(this,void 0,void 0,(function*(){var l,a,r,d,c,f,g;const b=null!=="2026.05.20-2b5dd59"?"2026.05.20-2b5dd59":"unknown",v=t.get(),m=null!==(d=null!==(a=null===(l=v.model)||void 0===l?void 0:l.displayName)&&void 0!==a?a:null===(r=v.model)||void 0===r?void 0:r.modelId)&&void 0!==d?d:"Auto",p=s().platform(),y=s().arch(),h=(0,i.detectTerminalProgram)(),q=(0,i.detectShell)(),R=u.d.getLastParentAgentRequestId();let I=null,A=null;try{const t=yield e.getAccessToken(),l=yield e.getRefreshToken();if(t&&l){try{I=null!==(c=(yield n.getMe(new o.GetMeRequest({}))).email)&&void 0!==c?c:null}catch(e){}try{A=null!==(g=null===(f=(yield n.getPlanInfo(new o.GetPlanInfoRequest({}))).planInfo)||void 0===f?void 0:f.planName)&&void 0!==g?g:null}catch(e){}}}catch(e){}return{cliVersion:b,model:m,subscriptionTier:A,osPlatform:p,osArch:y,userEmail:I,terminalProgram:h,shell:q,lastRequestId:R}}))}function g(e,t,n){return d(this,arguments,void 0,(function*(e,t,n,l={}){var s,o;const u=null!==(s=l.format)&&void 0!==s?s:"text";let i=0;try{const l=yield f(e,t,n);"json"===u?(0,r.OT)(JSON.stringify(l,null,2)):(0,r.OT)(function(e){var t,n;const l=[{label:"CLI Version",value:e.cliVersion},{label:"Model",value:e.model},{label:"Subscription Tier",value:null!==(t=e.subscriptionTier)&&void 0!==t?t:"Unknown"},{label:"OS",value:`${e.osPlatform} (${e.osArch})`},{label:"Terminal",value:e.terminalProgram},{label:"Shell",value:e.shell}];return e.lastRequestId&&l.push({label:"Last Request ID",value:e.lastRequestId}),l.push({label:"User Email",value:null!==(n=e.userEmail)&&void 0!==n?n:"Not logged in"}),`${a.Ay.bold.cyan("About Cursor CLI")}\n\n${l.map((e=>`${a.Ay.dim(e.label.padEnd(c))}${e.value}`)).join("\n")}`}(l))}catch(e){i=1;const t=String(e&&"object"==typeof e&&"message"in e&&null!==(o=e.message)&&void 0!==o?o:e);"json"===u?(0,r.OT)(JSON.stringify({status:"error",message:`Failed to get about info: ${t}`},null,2)):(0,r.p2)(a.Ay.red(`Failed to get about info: ${t}`))}finally{process.exit(i)}}))}},"./src/state/session.ts":(e,t,n)=>{n.d(t,{d:()=>o});const l=Object.seal({lastRequest:null,lastParentAgentRequest:null});function s(e,t){return{id:e,timestamp:Date.now(),path:null==t?void 0:t.path}}const o=Object.seal({get lastRequest(){return l.lastRequest},recordLastRequest(e,t){l.lastRequest=s(e,t)},recordLastParentAgentRequest(e,t){l.lastParentAgentRequest=s(e,t)},recordRequestFromMiddleware(e){const t={path:e.inner.url};l.lastRequest=s(e.requestId,t),e.inner.header.get("x-parent-request-id")||(l.lastParentAgentRequest=s(e.requestId,t))},getLastRequestId(){var e,t;return null!==(t=null===(e=l.lastRequest)||void 0===e?void 0:e.id)&&void 0!==t?t:null},getLastRequest:()=>l.lastRequest,getLastParentAgentRequestId(){var e,t;return null!==(t=null===(e=l.lastParentAgentRequest)||void 0===e?void 0:e.id)&&void 0!==t?t:null},clearLastRequest(){l.lastRequest=null,l.lastParentAgentRequest=null}})}};