try{!function(){var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{},n=(new e.Error).stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="348535b6-4edf-4bd4-9771-9372f0e7768a",e._sentryDebugIdIdentifier="sentry-dbid-348535b6-4edf-4bd4-9771-9372f0e7768a")}()}catch(e){}!function(){try{("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{}).SENTRY_RELEASE={id:"agent-cli@2026.05.20-2b5dd59"}}catch(e){}}(),exports.id=7469,exports.ids=[7469],exports.modules={"./src/commands/install-shell-integration.ts":(e,n,t)=>{t.r(n),t.d(n,{handleInstallShellIntegration:()=>c});var l=t("node:fs"),i=t("node:os"),o=t("node:path"),s=t.n(o),d=t("./src/console-io.ts");const r='eval "$(~/.local/bin/agent shell-integration zsh)"',a='eval "$(~/.local/bin/cursor-agent shell-integration zsh)"';function c(){const e=s().join((0,i.homedir)(),".zshrc");try{let n="";try{n=(0,l.readFileSync)(e,"utf8")}catch(e){if("ENOENT"!==e.code)throw e;n=""}if(n.includes(r)||n.includes(a))return void(0,d.p2)("Shell integration is already installed in ~/.zshrc");const t=`${r}\n${n}`;(0,l.writeFileSync)(e,t,"utf8"),(0,d.p2)("Shell integration installed successfully!"),(0,d.p2)("Please restart your terminal or run 'source ~/.zshrc' to activate.")}catch(e){(0,d.p2)(`Failed to install shell integration: ${String(e)}`),process.exit(1)}}}};